@@ -1,6 +1,7 @@
 #include<cstdio>
 #include<cstdlib>
 #include <cstring>
+#include<cmath>
 
 #include <R.h>
 #include <Rmath.h>
@@ -10,7 +11,9 @@
 
 #include "c2121a_poisson_mc_hier2_lev0.h"
 
-static const char *rcsId = "$Id: c2121a_poisson_mc_hier2_lev0.cpp,v 1.5 2016/08/25 15:13:14 clb13102 Exp clb13102 $";
+using namespace std;
+
+static const char *rcsId = "$Id: c2121a_poisson_mc_hier2_lev0.cpp,v 1.6 2017/03/22 16:12:09 clb13102 Exp clb13102 $";
 
 const char* c2121a_poisson_mc_hier2_lev0::sColType = "type";
 const char* c2121a_poisson_mc_hier2_lev0::sColVariable = "variable";
