@@ -2,6 +2,7 @@
 #include<cstdlib>
 
 #include <cstring>
+#include<cmath>
 
 #include <R.h>
 #include <Rmath.h>
@@ -14,7 +15,9 @@
 #include "c2121a_poisson_mc_hier3_lev0.h"
 #include "c212BB_poisson_mc_hier3_lev0.h"
 
-static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev0.cpp,v 1.15 2016/08/25 15:13:14 clb13102 Exp clb13102 $";
+using namespace std;
+
+static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev0.cpp,v 1.16 2017/03/22 16:12:09 clb13102 Exp clb13102 $";
 
 const char* c212BB_poisson_mc_hier3_lev0::sMonitor_pi = "pi";
 const char* c212BB_poisson_mc_hier3_lev0::sMonitor_alpha_pi = "alpha.pi";
@@ -1230,7 +1233,7 @@ double c212BB_poisson_mc_hier3_lev0::log_f_alpha_pi(int c, int l, double alpha)
 		log_pi_sum += log(gPi[c][l][b]);
 	}
 
-	f = ((double)gNumBodySys[l]) * (lgamma(alpha + beta_pi[c][l]) - lgamma(alpha))
+	f = ((double)gNumBodySys[l]) * (lgammafn(alpha + beta_pi[c][l]) - lgammafn(alpha))
 							+ (alpha - 1.0) * log_pi_sum - alpha * lambda_alpha; 
 	return(f);
 }
@@ -1398,7 +1401,7 @@ double c212BB_poisson_mc_hier3_lev0::log_f_beta_pi(int c, int l, double beta)
         log_sum += log(1.0 - gPi[c][l][b]);
     }
 
-    f = ((double)gNumBodySys[l]) * (lgamma(alpha_pi[c][l] + beta) - lgamma(beta)) + (beta - 1.0) * log_sum - beta * lambda_beta; 
+    f = ((double)gNumBodySys[l]) * (lgammafn(alpha_pi[c][l] + beta) - lgammafn(beta)) + (beta - 1.0) * log_sum - beta * lambda_beta; 
     return(f);
 }
 
