@@ -2,6 +2,7 @@
 #include<cstdlib>
 
 #include<cstring>
+#include<cmath>
 
 #include <R.h>
 #include <Rmath.h>
@@ -15,7 +16,9 @@
 #include "c212BB_poisson_mc_hier3_lev0.h"
 #include "c212BB_poisson_mc_hier3_lev2.h"
 
-static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev2.cpp,v 1.15 2016/08/25 15:13:14 clb13102 Exp clb13102 $";
+using namespace std;
+
+static const char *rcsId = "$Id: c212BB_poisson_mc_hier3_lev2.cpp,v 1.16 2017/03/22 16:12:09 clb13102 Exp clb13102 $";
 
 c212BB_poisson_mc_hier3_lev2::c212BB_poisson_mc_hier3_lev2()
 {
@@ -920,7 +923,7 @@ double c212BB_poisson_mc_hier3_lev2::log_f_alpha_pi(int c, double alpha)
 			log_pi_sum += log(gPi[c][l][b]);
 		}
 
-		f = f + ((double)gNumBodySys[l]) * (lgamma(alpha + beta_pi[c]) - lgamma(alpha));
+		f = f + ((double)gNumBodySys[l]) * (lgammafn(alpha + beta_pi[c]) - lgammafn(alpha));
 
 		f = f + (alpha - 1.0)*log_pi_sum;
 	}
@@ -1090,7 +1093,7 @@ double c212BB_poisson_mc_hier3_lev2::log_f_beta_pi(int c, double beta)
 			log_sum += log(1 - gPi[c][l][b]);
 		}
 
-		f = f + ((double)gNumBodySys[l]) * (lgamma(alpha_pi[c] + beta) - lgamma(beta));
+		f = f + ((double)gNumBodySys[l]) * (lgammafn(alpha_pi[c] + beta) - lgammafn(beta));
 
 		f = f + (beta - 1.0)*log_sum;
 	}
